Tutorials — cnnclustering documentation

# Tutorials

Density based common-nearest-neighbour (CNN) clustering can be applied to arbitrary, high-dimensional data sets. Here we demonstrate how to use the cnnclustering Python package to assign cluster labels to data points in different contexts (cnn module) and how to build a core-set Markov-state model (csMSM) on top of a cluster result (cmsm module).

- Basic usage of the cnn module
- scikit-learn Toy data sets
- Hierarchical clustering basics
- Data input formats
- Density based clustering explained
- Molecular dynamics application example